from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Array, String, Boolean, File, Int

Cpan_V0_1_0 = CommandToolBuilder(tool="cpan", base_command=["cpan"], inputs=[ToolInput(tag="in_shows_primary_maintainers", input_type=Array(t=String(), optional=True), prefix="-A", doc=InputDocumentation(doc="Shows the primary maintainers for the specified modules.")), ToolInput(tag="in_runs_make_clean", input_type=String(optional=True), prefix="-c", doc=InputDocumentation(doc="Runs a `make clean` in the specified module's directories.")), ToolInput(tag="in_show_changes_files", input_type=Array(t=String(), optional=True), prefix="-C", doc=InputDocumentation(doc="Show the Changes files for the specified modules")), ToolInput(tag="in_show_module_details", input_type=Array(t=String(), optional=True), prefix="-D", doc=InputDocumentation(doc="Show the module details. This prints one line for each out-of-date\nmodule (meaning, modules locally installed but have newer versions\non CPAN). Each line has three columns: module name, local version,\nand CPAN version.")), ToolInput(tag="in_force_specified_action", input_type=Boolean(optional=True), prefix="-f", doc=InputDocumentation(doc="Force the specified action, when it normally would have failed. Use\nthis to install a module even if its tests fail. When you use this\noption, -i is not optional for installing a module when you need to\nforce it:\n% cpan -f -i Module::Foo")), ToolInput(tag="in_turn_cpanpms_attempts", input_type=Boolean(optional=True), prefix="-F", doc=InputDocumentation(doc="Turn off CPAN.pm's attempts to lock anything. You should be careful\nwith this since you might end up with multiple scripts trying to\nmuck in the same directory. This isn't so much of a concern if\nyou're loading a special config with '-j', and that config sets up\nits own work directories.")), ToolInput(tag="in_downloads_latest_distribution", input_type=Array(t=String(), optional=True), prefix="-g", doc=InputDocumentation(doc="Downloads to the current directory the latest distribution of the\nmodule.")), ToolInput(tag="in_install_specified_modules", input_type=Array(t=String(), optional=True), prefix="-i", doc=InputDocumentation(doc="Install the specified modules. With no other switches, this switch\nis implied.")), ToolInput(tag="in_load_too_bad", input_type=Boolean(optional=True), prefix="-I", doc=InputDocumentation(doc="Load 'local::lib' (think like '-I' for loading lib paths). Too bad\n'-l' was already taken.")), ToolInput(tag="in_load_file_has", input_type=File(optional=True), prefix="-j", doc=InputDocumentation(doc="Load the file that has the CPAN configuration data. This should have\nthe same format as the standard CPAN/Config.pm file, which defines\n$CPAN::Config as an anonymous hash.")), ToolInput(tag="in_dump_configuration_same", input_type=Boolean(optional=True), prefix="-J", doc=InputDocumentation(doc="Dump the configuration in the same format that CPAN.pm uses. This is\nuseful for checking the configuration as well as using the dump as a\nstarting point for a new, custom configuration.")), ToolInput(tag="in_list_installed_modules", input_type=Boolean(optional=True), prefix="-l", doc=InputDocumentation(doc="List all installed modules with their versions")), ToolInput(tag="in_list_modules_specified", input_type=Array(t=String(), optional=True), prefix="-L", doc=InputDocumentation(doc="List the modules by the specified authors.")), ToolInput(tag="in_make_specified_modules", input_type=Boolean(optional=True), prefix="-m", doc=InputDocumentation(doc="Make the specified modules.")), ToolInput(tag="in_mirror_commaseparated_list", input_type=Int(optional=True), prefix="-M", doc=InputDocumentation(doc=",mirror2,...\nA comma-separated list of mirrors to use for just this run. The '-P'\noption can find them for you automatically.")), ToolInput(tag="in_do_dry_run", input_type=Boolean(optional=True), prefix="-n", doc=InputDocumentation(doc="Do a dry run, but don't actually install anything. (unimplemented)")), ToolInput(tag="in_show_outofdate_modules", input_type=Boolean(optional=True), prefix="-O", doc=InputDocumentation(doc="Show the out-of-date modules.")), ToolInput(tag="in_ping_configured_mirrors", input_type=Boolean(optional=True), prefix="-p", doc=InputDocumentation(doc="Ping the configured mirrors and print a report")), ToolInput(tag="in_find_best_mirrors", input_type=Boolean(optional=True), prefix="-P", doc=InputDocumentation(doc="Find the best mirrors you could be using and use them for the\ncurrent session.")), ToolInput(tag="in_recompiles_dynamically_loaded", input_type=Boolean(optional=True), prefix="-r", doc=InputDocumentation(doc="Recompiles dynamically loaded modules with CPAN::Shell->recompile.")), ToolInput(tag="in_drop_cpanpm_shell", input_type=Boolean(optional=True), prefix="-s", doc=InputDocumentation(doc="Drop in the CPAN.pm shell. This command does this automatically if\nyou don't specify any arguments.")), ToolInput(tag="in_run_make_test", input_type=Array(t=String(), optional=True), prefix="-t", doc=InputDocumentation(doc="Run a `make test` on the specified modules.")), ToolInput(tag="in_test_modules_simply", input_type=Boolean(optional=True), prefix="-T", doc=InputDocumentation(doc="Do not test modules. Simply install them.")), ToolInput(tag="in_upgrade_installed_modules", input_type=Boolean(optional=True), prefix="-u", doc=InputDocumentation(doc="Upgrade all installed modules. Blindly doing this can really break\nthings, so keep a backup.")), ToolInput(tag="in_print_script_version", input_type=Boolean(optional=True), prefix="-v", doc=InputDocumentation(doc="Print the script version and CPAN.pm version then exit.")), ToolInput(tag="in_print_detailed_information", input_type=Boolean(optional=True), prefix="-V", doc=InputDocumentation(doc="Print detailed information about the cpan client.")), ToolInput(tag="in_unimplementedturn_cpan_warnings", input_type=Boolean(optional=True), prefix="-w", doc=InputDocumentation(doc="UNIMPLEMENTED\nTurn on cpan warnings. This checks various things, like directory\npermissions, and tells you about problems you might have.")), ToolInput(tag="in_find_close_matches", input_type=Array(t=String(), optional=True), prefix="-x", doc=InputDocumentation(doc="Find close matches to the named modules that you think you might\nhave mistyped. This requires the optional installation of\nText::Levenshtein or Text::Levenshtein::Damerau.")), ToolInput(tag="in_dump_namespaces_standard", input_type=Boolean(optional=True), prefix="-X", doc=InputDocumentation(doc="Dump all the namespaces to standard output.")), ToolInput(tag="in_cpan", input_type=String(), position=0, doc=InputDocumentation(doc="# without arguments, but some switches")), ToolInput(tag="in_options", input_type=String(), position=0, doc=InputDocumentation(doc="-a  Creates a CPAN.pm autobundle with CPAN::Shell->autobundle.")), ToolInput(tag="in_unimplemented", input_type=String(), position=1, doc=InputDocumentation(doc="Download to the current directory the latest distribution of the")), ToolInput(tag="in_examples", input_type=String(), position=0, doc=InputDocumentation(doc="# print a help message\ncpan -h\n# print the version numbers\ncpan -v\n# create an autobundle\ncpan -a\n# recompile modules\ncpan -r\n# upgrade all installed modules\ncpan -u\n# install modules ( sole -i is optional )\ncpan -i Netscape::Booksmarks Business::ISBN\n# force install modules ( must use -i )\ncpan -fi CGI::Minimal URI\n# install modules but without testing them\ncpan -Ti CGI::Minimal URI")), ToolInput(tag="in_noninteractive_testing", input_type=String(), position=0, doc=InputDocumentation(doc="Assume no one is paying attention and skips prompts for\ndistributions that do that correctly. cpan(1) sets this to 1 unless\nit already has a value (even if that value is false).")), ToolInput(tag="in_perl_mm_use_default", input_type=String(), position=1, doc=InputDocumentation(doc="Use the default answer for a prompted questions. cpan(1) sets this\nto 1 unless it already has a value (even if that value is false).")), ToolInput(tag="in_cpan_opts", input_type=String(), position=2, doc=InputDocumentation(doc="As with 'PERL5OPTS', a string of additional cpan(1) options to add\nto those you specify on the command line.")), ToolInput(tag="in_cpan_script_loglevel", input_type=String(), position=3, doc=InputDocumentation(doc="The log level to use, with either the embedded, minimal logger or\nLog::Log4perl if it is installed. Possible values are the same as\nthe 'Log::Log4perl' levels: 'TRACE', 'DEBUG', 'INFO', 'WARN',\n'ERROR', and 'FATAL'. The default is 'INFO'.")), ToolInput(tag="in_git_command", input_type=String(), position=4, doc=InputDocumentation(doc="The path to the 'git' binary to use for the Git features. The\ndefault is '/usr/local/bin/git'."))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Cpan_V0_1_0().translate("wdl", allow_empty_container=True)

